@@ -20,12 +20,14 @@ public:
     QRegExp urlPattern() const;
     bool urlSupported(const QUrl &url) const;
     void checkUrl(const QUrl &url);
-    void getDownloadUrl(const QUrl &url);
+    void getDownloadRequest(const QUrl &url);
     void login(const QString &username, const QString &password);
     inline bool loginSupported() const { return true; }
     inline bool recaptchaRequired() const { return true; }
     inline QString recaptchaKey() const { return m_captchaKey; }
     inline QString recaptchaServiceName() const { return QString("Cramit"); }
+    inline int maximumConnections() const { return m_connections; }
+    bool cancelCurrentOperation();
 
 public slots:
     void submitCaptchaResponse(const QString &challenge, const QString &response);
@@ -43,11 +45,15 @@ private slots:
     void updateWaitTime();
     void onWaitFinished();
 
+signals:
+    void currentOperationCancelled();
+
 private:
     QString m_fileId;
     QString m_captchaKey;
     QTimer *m_waitTimer;
     int m_waitTime;
+    int m_connections;
 };
 
 #endif // CRAMIT_H
